package location

import (
	"github.com/gofiber/fiber/v2"
	"matrix-middle-service/pkg/database"
	"matrix-middle-service/pkg/database/model"
	"matrix-middle-service/pkg/logger"
	response "matrix-middle-service/pkg/resp"
	"matrix-middle-service/pkg/resp/errorx"
	"matrix-middle-service/pkg/utils/sonyflake"
	"matrix-middle-service/pkg/utils/time"
)

func SetupLocation(r fiber.Router) {
	api := r.Group("/location")
	postLocation(api)
}

type Data struct {
	CallbackTime time.Time `json:"callbackTime"`
	LocationTime time.Time `json:"locationTime"`
	LocationType int       `json:"locationType,omitempty"`
	Latitude     float64   `json:"latitude,omitempty"`
	Longitude    float64   `json:"longitude,omitempty"`
	Accuracy     float64   `json:"accuracy,omitempty"`
	Altitude     float64   `json:"altitude,omitempty"`
	Bearing      float64   `json:"bearing,omitempty"`
	Speed        float64   `json:"speed,omitempty"`
	Country      string    `json:"country,omitempty"`
	Province     string    `json:"province,omitempty"`
	City         string    `json:"city,omitempty"`
	District     string    `json:"district,omitempty"`
	Street       string    `json:"street,omitempty"`
	StreetNumber string    `json:"streetNumber,omitempty"`
	CityCode     string    `json:"cityCode,omitempty"`
	AdCode       string    `json:"adCode,omitempty"`
	Address      string    `json:"address,omitempty"`
	Description  string    `json:"description,omitempty"`
}

// postLocation
// @Summary      上报定位信息
// @Description  上报定位信息
// @Tags         Record
// @Accept       json
// @Produce      json
// @Success      200  {object}  response.Response
// @Failure	     default {object}  errorx.CodeErrorResponse
// @Router       /record/location/post [post]
func postLocation(api fiber.Router) {
	api.Post("/post", func(ctx *fiber.Ctx) error {
		data := &model.LocationRecord{}
		err := ctx.BodyParser(data)
		if err != nil {
			logger.Log().Error(err)
			return ctx.JSON(errorx.ParseError(err))
		}

		data.Id = sonyflake.NextStrId()
		return database.Exec(func(db database.DataBase) error {
			err := db.RecordLocation(data)
			if err = errorx.ParseError(err); err != nil {
				return ctx.JSON(err)
			}
			return ctx.JSON(response.NewResponse(data))
		})
	})
}
